==> haskell-tar-0.5.1.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tar
version:              0.5.1.1
visibility:           public
id:                   tar-0.5.1.1-6bOHQHvu5SQAWXBFOCvCJ3
key:                  tar-0.5.1.1-6bOHQHvu5SQAWXBFOCvCJ3
license:              BSD-3-Clause
copyright:
    2007 Bjorn Bringert <bjorn@bringert.net>
    2008-2016 Duncan Coutts <duncan@community.haskell.org>

maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:
    Duncan Coutts <duncan@community.haskell.org>
    Bjorn Bringert <bjorn@bringert.net>

synopsis:             Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.

    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.

    It also provides features for random access to archive
    content using an index.

category:             Codec
abi:                  5a7b80e1e063a0fdeabc655bd48bba23
exposed:              True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index

hidden-modules:
    Codec.Archive.Tar.Types Codec.Archive.Tar.Read
    Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
    Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
    Codec.Archive.Tar.Index.IntTrie

import-dirs:          /usr/lib/ghc-8.10.3/site-local/tar-0.5.1.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/tar-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/tar-0.5.1.1
hs-libraries:         HStar-0.5.1.1-6bOHQHvu5SQAWXBFOCvCJ3
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 filepath-1.4.2.1 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html:         /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-0.5.1.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tar
version:              0.5.1.1
visibility:           public
id:                   tar-0.5.1.1-3iyqV9m4r4f8Jo14oY5sdb
key:                  tar-0.5.1.1-3iyqV9m4r4f8Jo14oY5sdb
license:              BSD-3-Clause
copyright:
    2007 Bjorn Bringert <bjorn@bringert.net>
    2008-2016 Duncan Coutts <duncan@community.haskell.org>

maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:
    Duncan Coutts <duncan@community.haskell.org>
    Bjorn Bringert <bjorn@bringert.net>

synopsis:             Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.

    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.

    It also provides features for random access to archive
    content using an index.

category:             Codec
abi:                  a4b464476f0c778449b521971ed1741b
exposed:              True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index

hidden-modules:
    Codec.Archive.Tar.Types Codec.Archive.Tar.Read
    Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
    Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
    Codec.Archive.Tar.Index.IntTrie

import-dirs:          /usr/lib/ghc-8.10.3/site-local/tar-0.5.1.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/tar-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/tar-0.5.1.1
hs-libraries:         HStar-0.5.1.1-3iyqV9m4r4f8Jo14oY5sdb
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 filepath-1.4.2.1 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html:         /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
